An easy to use module that creates ODS documents. Fork of odslib (https://github.com/TauPan/odslib) as looking unmaintained. Ported to Python3.x whilst retaining Python2.7 legacy compatibility.

Original author: Joseph Colton

Documentation: http://odslib3.readthedocs.io/en/master/

PyPi project page: https://pypi.org/project/odslib3


Installation
------------

Simply clone the repository and run the usual setuptools process::

  $> git clone https://github.com/Exelscior/odslib3.git && cd odslib3
  $> python setup.py {build,install}

